@@ -22,11 +22,6 @@
 # define ATTRIBUTE_UNUSED
 #endif
 
-/* Work around really old python.  */
-#if PY_MAJOR_VERSION == 2 && PY_MINOR_VERSION < 5
-typedef ssize_t Py_ssize_t;
-#endif
-
 #if !LIBVIR_CHECK_VERSION(4, 5, 0)
 typedef struct _virNWFilterBinding *virNWFilterBindingPtr;
 #endif
@@ -281,3 +276,7 @@ PyObject * libvirt_virDomainSnapshotPtrWrap(virDomainSnapshotPtr node);
   if (PyEval_ThreadsInitialized())			       \
     PyGILState_Release(_save);				       \
   } LIBVIRT_STMT_END
+
+#ifndef NULLSTR
+#define NULLSTR(s) ((s) ? (s) : "<null>")
+#endif
